"use client"

import { useState, useEffect } from "react"
import Image from "next/image"
import Link from "next/link"
import {
  ChevronRight,
  BarChart3,
  Search,
  Globe,
  TrendingUp,
  Zap,
  Menu,
  X,
  Phone,
  ArrowRight,
  CheckCircle,
} from "lucide-react"
import { Button } from "@/components/ui/button"
import { Card, CardContent, CardDescription, CardFooter, CardHeader, CardTitle } from "@/components/ui/card"

// Break down into smaller components
const Header = ({ scrollPosition, mobileMenuOpen, setMobileMenuOpen }) => {
  const navItems = ["HOME", "ABOUT US", "SERVICES", "PRICING", "PORTFOLIO", "BLOG", "CONTACT"]

  return (
    <>
      <header
        className={`fixed top-0 left-0 right-0 z-50 transition-all duration-300 ${
          scrollPosition > 50 ? "bg-black/80 backdrop-blur-md py-2" : "bg-transparent py-4"
        }`}
      >
        <div className="container mx-auto px-4">
          <div className="flex items-center justify-between">
            <Link href="/" className="flex items-center space-x-2">
              <div className="relative">
                <span className="text-3xl font-bold">
                  <span className="text-primary">SEO</span>
                  <span className="text-white">COMPANY</span>
                  <span className="text-primary">OC</span>
                </span>
                <div className="absolute -bottom-4 left-0 text-sm text-zinc-400 font-light tracking-wider">
                  DATA DRIVEN MARKETING
                </div>
              </div>
            </Link>

            {/* Desktop Navigation */}
            <nav className="hidden md:flex items-center space-x-8">
              {navItems.map((item, index) => (
                <Link
                  key={index}
                  href={`#${item.toLowerCase().replace(/\s+/g, "-")}`}
                  className="relative text-sm font-medium tracking-wide hover:text-primary transition-colors"
                >
                  {item}
                </Link>
              ))}
            </nav>

            <div className="hidden md:flex items-center">
              <Link
                href="tel:7142438571"
                className="flex items-center space-x-2 text-primary hover:text-primary/80 transition-colors"
              >
                <Phone className="h-4 w-4" />
                <span className="font-medium">(714) 243-8571</span>
              </Link>
            </div>

            {/* Mobile menu button */}
            <button
              className="md:hidden text-white focus:outline-none"
              onClick={() => setMobileMenuOpen(!mobileMenuOpen)}
            >
              {mobileMenuOpen ? <X className="h-6 w-6" /> : <Menu className="h-6 w-6" />}
            </button>
          </div>
        </div>
      </header>

      {/* Mobile Navigation - Simplified */}
      {mobileMenuOpen && (
        <div className="fixed inset-0 z-40 bg-black/95 md:hidden">
          <div className="flex flex-col items-center justify-center h-full space-y-8 p-4">
            {navItems.map((item, index) => (
              <Link
                key={index}
                href={`#${item.toLowerCase().replace(/\s+/g, "-")}`}
                className="text-xl font-medium tracking-wide hover:text-primary transition-colors"
                onClick={() => setMobileMenuOpen(false)}
              >
                {item}
              </Link>
            ))}
            <Link
              href="tel:7142438571"
              className="flex items-center space-x-2 text-primary hover:text-primary/80 transition-colors"
              onClick={() => setMobileMenuOpen(false)}
            >
              <Phone className="h-5 w-5" />
              <span className="font-medium">(714) 243-8571</span>
            </Link>
          </div>
        </div>
      )}
    </>
  )
}

// Hero section component
const Hero = ({ count }) => (
  <section className="relative pt-32 pb-20 md:pt-40 md:pb-32">
    <div className="container mx-auto px-4">
      <div className="grid grid-cols-1 lg:grid-cols-2 gap-12 items-center">
        <div className="space-y-6">
          <h1 className="text-4xl md:text-5xl lg:text-6xl font-bold leading-tight">
            <span className="block">Elevate Your</span>
            <span className="text-primary">Digital Presence</span>
            <span className="block">With Data-Driven SEO</span>
          </h1>
          <p className="text-lg md:text-xl text-zinc-300 max-w-xl">
            Unlock your business potential with cutting-edge SEO strategies that drive measurable results and
            sustainable growth.
          </p>
          <div className="flex flex-col sm:flex-row gap-4">
            <Button size="lg">
              <span>Get Free Analysis</span>
              <ChevronRight className="ml-2 h-4 w-4" />
            </Button>
            <Button variant="outline" size="lg">
              <span>Our Services</span>
            </Button>
          </div>
        </div>

        <div className="relative">
          <div className="relative z-10 rounded-2xl overflow-hidden border border-zinc-800 shadow-2xl shadow-primary/20">
            <Image
              src="/placeholder.svg?height=600&width=800"
              alt="SEO Analytics Dashboard"
              width={800}
              height={600}
              className="w-full h-auto"
            />
          </div>
        </div>
      </div>

      {/* Stats */}
      <div className="grid grid-cols-1 md:grid-cols-3 gap-8 mt-20 relative z-10">
        <div className="bg-zinc-900/50 backdrop-blur-sm border border-zinc-800 rounded-xl p-6 text-center">
          <div className="text-4xl font-bold text-primary mb-2">{count.clients}+</div>
          <div className="text-zinc-400">Satisfied Clients</div>
        </div>
        <div className="bg-zinc-900/50 backdrop-blur-sm border border-zinc-800 rounded-xl p-6 text-center">
          <div className="text-4xl font-bold text-primary mb-2">{count.projects}+</div>
          <div className="text-zinc-400">Projects Completed</div>
        </div>
        <div className="bg-zinc-900/50 backdrop-blur-sm border border-zinc-800 rounded-xl p-6 text-center">
          <div className="text-4xl font-bold text-primary mb-2">{count.ranking}%</div>
          <div className="text-zinc-400">Client Retention Rate</div>
        </div>
      </div>
    </div>
  </section>
)

// Services section component
const Services = () => {
  const services = [
    {
      title: "Search Engine Optimization",
      description: "Boost your website's visibility in search results with our data-driven SEO strategies.",
      icon: <Search className="h-10 w-10 text-primary" />,
      features: ["Keyword Research", "On-Page SEO", "Technical SEO", "Link Building"],
    },
    {
      title: "Local SEO",
      description: "Dominate local search results and attract more customers from your area.",
      icon: <Globe className="h-10 w-10 text-primary" />,
      features: ["Google Business Profile", "Local Citations", "Review Management", "Local Link Building"],
    },
    {
      title: "Content Marketing",
      description: "Create engaging content that attracts and converts your target audience.",
      icon: <BarChart3 className="h-10 w-10 text-primary" />,
      features: ["Content Strategy", "Blog Writing", "Infographics", "Video Content"],
    },
    {
      title: "Performance Analytics",
      description: "Track and analyze your website's performance with advanced analytics.",
      icon: <TrendingUp className="h-10 w-10 text-primary" />,
      features: ["Traffic Analysis", "Conversion Tracking", "User Behavior", "ROI Reporting"],
    },
  ]

  return (
    <section className="py-20 md:py-32 relative">
      <div className="container mx-auto px-4">
        <div className="text-center mb-16">
          <h2 className="text-3xl md:text-4xl font-bold mb-4">
            Our Digital Marketing <span className="text-primary">Services</span>
          </h2>
          <p className="text-zinc-400 max-w-2xl mx-auto">
            Comprehensive solutions tailored to your business needs, designed to maximize your online visibility and
            drive growth.
          </p>
        </div>

        <div className="grid grid-cols-1 md:grid-cols-2 lg:grid-cols-4 gap-6">
          {services.map((service, index) => (
            <Card key={index} className="bg-zinc-900/50 backdrop-blur-sm border-zinc-800 h-full">
              <CardHeader>
                <div className="mb-4">{service.icon}</div>
                <CardTitle className="text-xl">{service.title}</CardTitle>
                <CardDescription className="text-zinc-400">{service.description}</CardDescription>
              </CardHeader>
              <CardContent>
                <ul className="space-y-2">
                  {service.features.map((feature, i) => (
                    <li key={i} className="flex items-center">
                      <CheckCircle className="h-4 w-4 text-sky-400 mr-2" />
                      <span className="text-sm text-zinc-300">{feature}</span>
                    </li>
                  ))}
                </ul>
              </CardContent>
              <CardFooter>
                <Button variant="ghost" className="w-full">
                  <span>Learn More</span>
                  <ArrowRight className="ml-2 h-4 w-4" />
                </Button>
              </CardFooter>
            </Card>
          ))}
        </div>
      </div>
    </section>
  )
}

// Process section component
const Process = () => {
  const processSteps = [
    {
      title: "Research & Analysis",
      icon: <Search className="h-8 w-8" />,
      description: "In-depth analysis of your business, competitors, and target audience.",
    },
    {
      title: "Strategy Development",
      icon: <BarChart3 className="h-8 w-8" />,
      description: "Custom strategy tailored to your specific goals and market position.",
    },
    {
      title: "Implementation",
      icon: <Zap className="h-8 w-8" />,
      description: "Expert execution of SEO tactics with precision and attention to detail.",
    },
    {
      title: "Monitoring & Optimization",
      icon: <TrendingUp className="h-8 w-8" />,
      description: "Continuous tracking and refinement to maximize results.",
    },
  ]

  return (
    <section className="py-20 md:py-32 relative bg-zinc-900/50">
      <div className="container mx-auto px-4">
        <div className="text-center mb-16">
          <h2 className="text-3xl md:text-4xl font-bold mb-4">
            Our <span className="text-primary">Process</span>
          </h2>
          <p className="text-zinc-400 max-w-2xl mx-auto">
            A systematic approach to elevate your online presence and drive sustainable growth.
          </p>
        </div>

        <div className="grid grid-cols-1 md:grid-cols-2 lg:grid-cols-4 gap-8">
          {processSteps.map((step, index) => (
            <div key={index} className="relative">
              <div className="bg-zinc-800/50 backdrop-blur-sm border border-zinc-700 rounded-xl p-6 h-full">
                <div className="flex items-center justify-center w-16 h-16 rounded-full bg-sky-400/10 text-sky-400 mb-4">
                  {step.icon}
                </div>
                <div className="absolute top-6 right-6 text-4xl font-bold text-zinc-700/30">{index + 1}</div>
                <h3 className="text-xl font-bold mb-2">{step.title}</h3>
                <p className="text-zinc-400">{step.description}</p>
              </div>
            </div>
          ))}
        </div>
      </div>
    </section>
  )
}

// Footer component
const Footer = () => {
  const currentYear = new Date().getFullYear()

  return (
    <footer className="py-12 md:py-20 bg-black/80 border-t border-zinc-800">
      <div className="container mx-auto px-4">
        <div className="grid grid-cols-1 md:grid-cols-2 lg:grid-cols-4 gap-12">
          <div>
            <Link href="/" className="flex items-center space-x-2 mb-6">
              <span className="text-2xl font-bold">
                <span className="text-primary">SEO</span>
                <span className="text-white">COMPANY</span>
                <span className="text-primary">OC</span>
              </span>
            </Link>
            <p className="text-zinc-400 mb-6">
              Data-driven digital marketing solutions that deliver measurable results and sustainable growth.
            </p>
          </div>

          <div>
            <h3 className="text-lg font-bold mb-6">Services</h3>
            <ul className="space-y-4">
              {["Search Engine Optimization", "Local SEO", "Content Marketing"].map((service, index) => (
                <li key={index}>
                  <Link
                    href={`#${service.toLowerCase().replace(/\s+/g, "-")}`}
                    className="text-zinc-400 hover:text-primary transition-colors flex items-center"
                  >
                    <ChevronRight className="h-3 w-3 mr-2 text-sky-400" />
                    <span>{service}</span>
                  </Link>
                </li>
              ))}
            </ul>
          </div>

          <div>
            <h3 className="text-lg font-bold mb-6">Company</h3>
            <ul className="space-y-4">
              {["About Us", "Our Team", "Case Studies"].map((item, index) => (
                <li key={index}>
                  <Link
                    href={`#${item.toLowerCase().replace(/\s+/g, "-")}`}
                    className="text-zinc-400 hover:text-primary transition-colors flex items-center"
                  >
                    <ChevronRight className="h-3 w-3 mr-2 text-sky-400" />
                    <span>{item}</span>
                  </Link>
                </li>
              ))}
            </ul>
          </div>

          <div>
            <h3 className="text-lg font-bold mb-6">Contact</h3>
            <ul className="space-y-4 text-zinc-400">
              <li className="flex items-start">
                <svg
                  xmlns="http://www.w3.org/2000/svg"
                  className="h-5 w-5 mr-3 text-sky-400 shrink-0 mt-0.5"
                  viewBox="0 0 24 24"
                  fill="none"
                  stroke="currentColor"
                  strokeWidth="2"
                  strokeLinecap="round"
                  strokeLinejoin="round"
                >
                  <path d="M21 10c0 7-9 13-9 13s-9-6-9-13a9 9 0 0 1 18 0z"></path>
                  <circle cx="12" cy="10" r="3"></circle>
                </svg>
                <span>Orange County, CA</span>
              </li>
              <li className="flex items-start">
                <Phone className="h-5 w-5 mr-3 text-sky-400 shrink-0 mt-0.5" />
                <span>(714) 243-8571</span>
              </li>
              <li className="flex items-start">
                <svg
                  xmlns="http://www.w3.org/2000/svg"
                  className="h-5 w-5 mr-3 text-sky-400 shrink-0 mt-0.5"
                  viewBox="0 0 24 24"
                  fill="none"
                  stroke="currentColor"
                  strokeWidth="2"
                  strokeLinecap="round"
                  strokeLinejoin="round"
                >
                  <path d="M4 4h16c1.1 0 2 .9 2 2v12c0 1.1-.9 2-2 2H4c-1.1 0-2-.9-2-2V6c0-1.1.9-2 2-2z"></path>
                  <polyline points="22,6 12,13 2,6"></polyline>
                </svg>
                <span>info@seocompanyoc.com</span>
              </li>
            </ul>
          </div>
        </div>

        <div className="border-t border-zinc-800 mt-12 pt-8 flex flex-col md:flex-row justify-between items-center">
          <p className="text-zinc-500 text-sm">© {currentYear} SEO Company OC. All rights reserved.</p>
          <div className="flex space-x-6 mt-4 md:mt-0">
            <Link href="#privacy-policy" className="text-zinc-500 hover:text-primary text-sm">
              Privacy Policy
            </Link>
            <Link href="#terms-of-service" className="text-zinc-500 hover:text-primary text-sm">
              Terms of Service
            </Link>
          </div>
        </div>
      </div>
    </footer>
  )
}

// Main component
export default function Home() {
  const [mobileMenuOpen, setMobileMenuOpen] = useState(false)
  const [scrollPosition, setScrollPosition] = useState(0)
  const [count, setCount] = useState({ clients: 250, projects: 500, ranking: 98 })

  // Update scroll position
  useEffect(() => {
    const updatePosition = () => {
      setScrollPosition(window.scrollY)
    }
    window.addEventListener("scroll", updatePosition)
    return () => window.removeEventListener("scroll", updatePosition)
  }, [])

  return (
    <div className="min-h-screen bg-gradient-to-b from-black to-zinc-900 text-white">
      {/* Static background instead of animated */}
      <div className="fixed inset-0 z-0 pointer-events-none">
        <div className="absolute top-0 left-0 w-full h-full">
          <div className="absolute top-1/4 left-1/4 w-1/3 h-1/3 bg-primary/10 rounded-full blur-3xl" />
          <div className="absolute bottom-1/4 right-1/4 w-1/3 h-1/3 bg-primary/10 rounded-full blur-3xl" />
        </div>
      </div>

      <Header scrollPosition={scrollPosition} mobileMenuOpen={mobileMenuOpen} setMobileMenuOpen={setMobileMenuOpen} />

      <main>
        <Hero count={count} />
        <Services />
        <Process />
      </main>

      <Footer />

      {/* Simplified back to top button */}
      {scrollPosition > 300 && (
        <button
          className="fixed bottom-8 right-8 z-50 w-12 h-12 rounded-full bg-primary flex items-center justify-center text-white shadow-lg"
          onClick={() => window.scrollTo({ top: 0, behavior: "smooth" })}
        >
          <svg
            xmlns="http://www.w3.org/2000/svg"
            className="h-6 w-6"
            viewBox="0 0 24 24"
            fill="none"
            stroke="currentColor"
            strokeWidth="2"
            strokeLinecap="round"
            strokeLinejoin="round"
          >
            <polyline points="18 15 12 9 6 15"></polyline>
          </svg>
        </button>
      )}
    </div>
  )
}

